netapp_ontap.models.metrocluster_diagnostics_volume API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.metrocluster_diagnostics_volume`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class MetroclusterDiagnosticsVolumeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MetroclusterDiagnosticsVolume object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `details: List[MetroclusterDiagDetails] GET`

    Display details of the MetroCluster check for volumes.

  `state: str GET`

    Status of diagnostic operation for this component.

    Valid choices:

    - ok
    - warning
    - not_run
    - not_applicable
  `summary: ErrorArguments GET`

    The summary field of the metrocluster_diagnostics_volume.

  `timestamp: ImpreciseDateTime GET`

    Time of the most recent diagnostic operation for this component

    Example: 2016-03-10T22:35:16.000+0000